==> qmmp-plugin-pack-0.12.2.tar.bz2: qmmp-plugin-pack-0.12.2/src/Visual/goom/translations/goom_plugin_pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>GoomWidget</name>
    <message>
        <location filename="../goomwidget.cpp" line="137"/>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="187"/>
        <source>Refresh Rate</source>
        <translation>Odświeżanie</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="190"/>
        <source>60 fps</source>
        <translation>60 kl./s</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="191"/>
        <source>50 fps</source>
        <translation>50 kl./s</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="192"/>
        <source>25 fps</source>
        <translation>25 kl./s</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="198"/>
        <source>&amp;Show Title</source>
        <translation>Pokaż &amp;tytuł</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="201"/>
        <source>&amp;Full Screen</source>
        <translation>&amp;Pełny ekran</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="201"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
<context>
    <name>VisualGoomFactory</name>
    <message>
        <location filename="../visualgoomfactory.cpp" line="30"/>
        <source>Goom</source>
        <translation>Goom</translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="49"/>
        <source>About Goom Visual Plugin</source>
        <translation>O wtyczce wizualnej Goom</translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="50"/>
        <source>Qmmp Goom Visual Plugin</source>
        <translation>Wtyczka wizualna Goom dla Qmmp</translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="51"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Napisana przez: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="52"/>
        <source>Based on the source code from the Goom project</source>
        <translation>Na podstawie kodu źródłowego z projektu Goom </translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="53"/>
        <source>Goom project developers:</source>
        <translation>Programiści projektu Goom:</translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="54"/>
        <source>Jean-Christophe Hoelt &lt;jeko@ios-software.com&gt;</source>
        <translation>Jean-Christophe Hoelt &lt;jeko@ios-software.com&gt;</translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="55"/>
        <source>Guillaume Borios &lt;gyom@ios-software.com&gt;</source>
        <translation>Guillaume Borios &lt;gyom@ios-software.com&gt;</translation>
    </message>
</context>
</TS>

==> qmmp-plugin-pack-1.2.0.tar.bz2: qmmp-plugin-pack-1.2.0/src/Visual/goom/translations/goom_plugin_pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<context>
    <name>GoomWidget</name>
    <message>
        <location filename="../goomwidget.cpp" line="137"/>
        <source>%1 - %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="187"/>
        <source>Refresh Rate</source>
        <translation>Odświeżanie</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="190"/>
        <source>60 fps</source>
        <translation type="unfinished">25 klatek {60 ?}</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="191"/>
        <source>50 fps</source>
        <translation>50 klatek</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="192"/>
        <source>25 fps</source>
        <translation>25 klatek</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="198"/>
        <source>&amp;Show Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="201"/>
        <source>&amp;Full Screen</source>
        <translation>Pełny Ekran</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="201"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
<context>
    <name>VisualGoomFactory</name>
    <message>
        <location filename="../visualgoomfactory.cpp" line="31"/>
        <source>Goom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="50"/>
        <source>About Goom Visual Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="51"/>
        <source>Qmmp Goom Visual Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="53"/>
        <source>Based on the source code from the Goom project</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="54"/>
        <source>Goom project developers:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="55"/>
        <source>Jean-Christophe Hoelt &lt;jeko@ios-software.com&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="56"/>
        <source>Guillaume Borios &lt;gyom@ios-software.com&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
